@@ -71,7 +71,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 30146290 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 31831145 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -481,13 +481,13 @@ if [ -d "/var/lib/dkms/nvidia" ]; then
     done
 fi
 
-# check the status of the nvidia-suspend, nvidia-hibernate, and nvidia-resume
-# systemd services
+# check the status of the nvidia-suspend, nvidia-hibernate, nvidia-resume
+# and nvidia-powerd systemd services
 
 systemctl=`which systemctl 2> /dev/null | head -n 1`
 
 if [ $? -eq 0 -a -x "$systemctl" ]; then
-    cmd="$systemctl status nvidia-suspend.service nvidia-hibernate.service nvidia-resume.service"
+    cmd="$systemctl status nvidia-suspend.service nvidia-hibernate.service nvidia-resume.service nvidia-powerd.service"
     (
         echo "____________________________________________"
         echo ""
@@ -811,7 +811,7 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
     echo ""
     echo "Scanning kernel log files for NVIDIA kernel messages:"
 
-    grep_args="-e NVRM -e nvidia- -e nvrm-nvlog"
+    grep_args="-e NVRM -e nvidia- -e nvrm-nvlog -e nvidia-powerd"
     logfound=0
     search_string_in_logs /var/log/messages "$grep_args" && logfound=1
     search_string_in_logs /var/log/kern.log "$grep_args" && logfound=1
@@ -1017,17 +1017,39 @@ done
 
 # List the mapping of DRM drivers to DRM device files
 (
+
     echo "____________________________________________"
     echo ""
 
-    for CARD in /sys/class/drm/*/device/driver ; do
-        echo_metadata $CARD
-    done
+    if [ -d "/sys/class/drm" ]; then
+        for CARD in /sys/class/drm/*/device/driver ; do
+            echo_metadata $CARD
+        done
+    else
+        echo "/sys/class/drm not present"
+    fi
 
     echo ""
 
 ) | $GZIP_CMD >> $LOG_FILENAME
 
+# List the mapping of PCI devices to DRM device files, and the existence and
+# permissions of the DRM device files themselves.
+(
+    echo "____________________________________________"
+    echo ""
+
+    if [ -d "/dev/dri" ]; then
+        for FILE in /dev/dri/by-path/* /dev/dri/card* /dev/dri/renderD*; do
+            echo_metadata $FILE
+        done
+    else
+        echo "/dev/dri not present"
+    fi
+
+    echo ""
+) | $GZIP_CMD >> $LOG_FILENAME
+
 # disable these when safemode is requested
 if [ $BUG_REPORT_SAFE_MODE -eq 0 ]; then
 
@@ -1144,6 +1166,21 @@ else
     ) | $GZIP_CMD >> $LOG_FILENAME
 fi
 
+# copy fabric manager (for NVSwitch based systems) default log file
+append_silent "/var/log/fabricmanager.log"
+# get fabric manager service status information
+systemctl=`which systemctl 2> /dev/null | head -n 1`
+if [ $? -eq 0 -a -x "$systemctl" ]; then
+    cmd="$systemctl status nvidia-fabricmanager.service"
+    (
+        echo "____________________________________________"
+        echo ""
+        echo "$cmd"
+        $cmd
+        echo ""
+    ) 2> /dev/null | $GZIP_CMD >> $LOG_FILENAME
+fi
+
 # Print information about the libglvnd libraries
 (
     if [ -e $GLVND_HELPER_BASE_PATH/glvnd_check ] ; then
